# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RoleArgs', 'Role']

@pulumi.input_type
class RoleArgs:
    def __init__(__self__, *,
                 role_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 max_session_duration: Optional[pulumi.Input[builtins.int]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input['RolePolicyArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['RoleTagArgs']]]] = None,
                 trust_policy_document: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Role resource.
        :param pulumi.Input[builtins.str] role_name: 角色名，长度1~64，支持英文、数字和.-_符号。
        :param pulumi.Input[builtins.str] description: 角色描述，长度不超过128。
        :param pulumi.Input[builtins.str] display_name: 角色显示名，长度不超过64。
        :param pulumi.Input[builtins.int] max_session_duration: 角色最大会话时间，角色最大会话时间。用于限制角色扮演产生的临时安全凭证的有效期的最大范围。取值范围：3600~43200，单位为秒，默认为43200。
        :param pulumi.Input[builtins.str] trust_policy_document: 角色信任策略，信任策略遵循IAM的策略语法中基于资源的策略规则。
        """
        pulumi.set(__self__, "role_name", role_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if max_session_duration is not None:
            pulumi.set(__self__, "max_session_duration", max_session_duration)
        if policies is not None:
            pulumi.set(__self__, "policies", policies)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if trust_policy_document is not None:
            pulumi.set(__self__, "trust_policy_document", trust_policy_document)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Input[builtins.str]:
        """
        角色名，长度1~64，支持英文、数字和.-_符号。
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        角色描述，长度不超过128。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        角色显示名，长度不超过64。
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="maxSessionDuration")
    def max_session_duration(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        角色最大会话时间，角色最大会话时间。用于限制角色扮演产生的临时安全凭证的有效期的最大范围。取值范围：3600~43200，单位为秒，默认为43200。
        """
        return pulumi.get(self, "max_session_duration")

    @max_session_duration.setter
    def max_session_duration(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_session_duration", value)

    @property
    @pulumi.getter
    def policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RolePolicyArgs']]]]:
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RolePolicyArgs']]]]):
        pulumi.set(self, "policies", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RoleTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RoleTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="trustPolicyDocument")
    def trust_policy_document(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        角色信任策略，信任策略遵循IAM的策略语法中基于资源的策略规则。
        """
        return pulumi.get(self, "trust_policy_document")

    @trust_policy_document.setter
    def trust_policy_document(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "trust_policy_document", value)


@pulumi.input_type
class _RoleState:
    def __init__(__self__, *,
                 create_date: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 is_service_linked_role: Optional[pulumi.Input[builtins.int]] = None,
                 max_session_duration: Optional[pulumi.Input[builtins.int]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input['RolePolicyArgs']]]] = None,
                 role_id: Optional[pulumi.Input[builtins.int]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['RoleTagArgs']]]] = None,
                 trn: Optional[pulumi.Input[builtins.str]] = None,
                 trust_policy_document: Optional[pulumi.Input[builtins.str]] = None,
                 update_date: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Role resources.
        :param pulumi.Input[builtins.str] create_date: 角色创建时间。
        :param pulumi.Input[builtins.str] description: 角色描述，长度不超过128。
        :param pulumi.Input[builtins.str] display_name: 角色显示名，长度不超过64。
        :param pulumi.Input[builtins.int] is_service_linked_role: 是否是服务关联角色, 0否，1是。
        :param pulumi.Input[builtins.int] max_session_duration: 角色最大会话时间，角色最大会话时间。用于限制角色扮演产生的临时安全凭证的有效期的最大范围。取值范围：3600~43200，单位为秒，默认为43200。
        :param pulumi.Input[builtins.int] role_id: 角色ID。
        :param pulumi.Input[builtins.str] role_name: 角色名，长度1~64，支持英文、数字和.-_符号。
        :param pulumi.Input[builtins.str] trn: 角色TRN。
        :param pulumi.Input[builtins.str] trust_policy_document: 角色信任策略，信任策略遵循IAM的策略语法中基于资源的策略规则。
        :param pulumi.Input[builtins.str] update_date: 角色更新时间。
        """
        if create_date is not None:
            pulumi.set(__self__, "create_date", create_date)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if is_service_linked_role is not None:
            pulumi.set(__self__, "is_service_linked_role", is_service_linked_role)
        if max_session_duration is not None:
            pulumi.set(__self__, "max_session_duration", max_session_duration)
        if policies is not None:
            pulumi.set(__self__, "policies", policies)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if trn is not None:
            pulumi.set(__self__, "trn", trn)
        if trust_policy_document is not None:
            pulumi.set(__self__, "trust_policy_document", trust_policy_document)
        if update_date is not None:
            pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        角色创建时间。
        """
        return pulumi.get(self, "create_date")

    @create_date.setter
    def create_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_date", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        角色描述，长度不超过128。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        角色显示名，长度不超过64。
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="isServiceLinkedRole")
    def is_service_linked_role(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        是否是服务关联角色, 0否，1是。
        """
        return pulumi.get(self, "is_service_linked_role")

    @is_service_linked_role.setter
    def is_service_linked_role(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "is_service_linked_role", value)

    @property
    @pulumi.getter(name="maxSessionDuration")
    def max_session_duration(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        角色最大会话时间，角色最大会话时间。用于限制角色扮演产生的临时安全凭证的有效期的最大范围。取值范围：3600~43200，单位为秒，默认为43200。
        """
        return pulumi.get(self, "max_session_duration")

    @max_session_duration.setter
    def max_session_duration(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_session_duration", value)

    @property
    @pulumi.getter
    def policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RolePolicyArgs']]]]:
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RolePolicyArgs']]]]):
        pulumi.set(self, "policies", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        角色ID。
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "role_id", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        角色名，长度1~64，支持英文、数字和.-_符号。
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RoleTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RoleTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def trn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        角色TRN。
        """
        return pulumi.get(self, "trn")

    @trn.setter
    def trn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "trn", value)

    @property
    @pulumi.getter(name="trustPolicyDocument")
    def trust_policy_document(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        角色信任策略，信任策略遵循IAM的策略语法中基于资源的策略规则。
        """
        return pulumi.get(self, "trust_policy_document")

    @trust_policy_document.setter
    def trust_policy_document(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "trust_policy_document", value)

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        角色更新时间。
        """
        return pulumi.get(self, "update_date")

    @update_date.setter
    def update_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_date", value)


@pulumi.type_token("bytepluscc:iam/role:Role")
class Role(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 max_session_duration: Optional[pulumi.Input[builtins.int]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RolePolicyArgs', 'RolePolicyArgsDict']]]]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RoleTagArgs', 'RoleTagArgsDict']]]]] = None,
                 trust_policy_document: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        角色（Role）是IAM体系里的一种虚拟身份，用于将账号内某些访问权限授予给各类身份实体，受信任的身份实体可扮演该角色来访问账号内的云资源。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        role_demo = bytepluscc.iam.Role("RoleDemo",
            role_name="RoleDemo",
            description="role attach policies",
            max_session_duration=3600,
            trust_policy_document=\"\"\"{
            "Statement": [
                {
                    "Effect": "Allow",
                    "Action": [
                        "sts:AssumeRole"
                    ],
                    "Principal": {
                        "IAM": [
                            "trn:iam::20000000xx:root"
                        ]
                    }
                }
            ]
        }\"\"\",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/role:Role example "role_name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 角色描述，长度不超过128。
        :param pulumi.Input[builtins.str] display_name: 角色显示名，长度不超过64。
        :param pulumi.Input[builtins.int] max_session_duration: 角色最大会话时间，角色最大会话时间。用于限制角色扮演产生的临时安全凭证的有效期的最大范围。取值范围：3600~43200，单位为秒，默认为43200。
        :param pulumi.Input[builtins.str] role_name: 角色名，长度1~64，支持英文、数字和.-_符号。
        :param pulumi.Input[builtins.str] trust_policy_document: 角色信任策略，信任策略遵循IAM的策略语法中基于资源的策略规则。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        角色（Role）是IAM体系里的一种虚拟身份，用于将账号内某些访问权限授予给各类身份实体，受信任的身份实体可扮演该角色来访问账号内的云资源。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        role_demo = bytepluscc.iam.Role("RoleDemo",
            role_name="RoleDemo",
            description="role attach policies",
            max_session_duration=3600,
            trust_policy_document=\"\"\"{
            "Statement": [
                {
                    "Effect": "Allow",
                    "Action": [
                        "sts:AssumeRole"
                    ],
                    "Principal": {
                        "IAM": [
                            "trn:iam::20000000xx:root"
                        ]
                    }
                }
            ]
        }\"\"\",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/role:Role example "role_name"
        ```

        :param str resource_name: The name of the resource.
        :param RoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 max_session_duration: Optional[pulumi.Input[builtins.int]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RolePolicyArgs', 'RolePolicyArgsDict']]]]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RoleTagArgs', 'RoleTagArgsDict']]]]] = None,
                 trust_policy_document: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleArgs.__new__(RoleArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["max_session_duration"] = max_session_duration
            __props__.__dict__["policies"] = policies
            if role_name is None and not opts.urn:
                raise TypeError("Missing required property 'role_name'")
            __props__.__dict__["role_name"] = role_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["trust_policy_document"] = trust_policy_document
            __props__.__dict__["create_date"] = None
            __props__.__dict__["is_service_linked_role"] = None
            __props__.__dict__["role_id"] = None
            __props__.__dict__["trn"] = None
            __props__.__dict__["update_date"] = None
        super(Role, __self__).__init__(
            'bytepluscc:iam/role:Role',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_date: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            is_service_linked_role: Optional[pulumi.Input[builtins.int]] = None,
            max_session_duration: Optional[pulumi.Input[builtins.int]] = None,
            policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RolePolicyArgs', 'RolePolicyArgsDict']]]]] = None,
            role_id: Optional[pulumi.Input[builtins.int]] = None,
            role_name: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RoleTagArgs', 'RoleTagArgsDict']]]]] = None,
            trn: Optional[pulumi.Input[builtins.str]] = None,
            trust_policy_document: Optional[pulumi.Input[builtins.str]] = None,
            update_date: Optional[pulumi.Input[builtins.str]] = None) -> 'Role':
        """
        Get an existing Role resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_date: 角色创建时间。
        :param pulumi.Input[builtins.str] description: 角色描述，长度不超过128。
        :param pulumi.Input[builtins.str] display_name: 角色显示名，长度不超过64。
        :param pulumi.Input[builtins.int] is_service_linked_role: 是否是服务关联角色, 0否，1是。
        :param pulumi.Input[builtins.int] max_session_duration: 角色最大会话时间，角色最大会话时间。用于限制角色扮演产生的临时安全凭证的有效期的最大范围。取值范围：3600~43200，单位为秒，默认为43200。
        :param pulumi.Input[builtins.int] role_id: 角色ID。
        :param pulumi.Input[builtins.str] role_name: 角色名，长度1~64，支持英文、数字和.-_符号。
        :param pulumi.Input[builtins.str] trn: 角色TRN。
        :param pulumi.Input[builtins.str] trust_policy_document: 角色信任策略，信任策略遵循IAM的策略语法中基于资源的策略规则。
        :param pulumi.Input[builtins.str] update_date: 角色更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleState.__new__(_RoleState)

        __props__.__dict__["create_date"] = create_date
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["is_service_linked_role"] = is_service_linked_role
        __props__.__dict__["max_session_duration"] = max_session_duration
        __props__.__dict__["policies"] = policies
        __props__.__dict__["role_id"] = role_id
        __props__.__dict__["role_name"] = role_name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["trn"] = trn
        __props__.__dict__["trust_policy_document"] = trust_policy_document
        __props__.__dict__["update_date"] = update_date
        return Role(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> pulumi.Output[builtins.str]:
        """
        角色创建时间。
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        角色描述，长度不超过128。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        角色显示名，长度不超过64。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="isServiceLinkedRole")
    def is_service_linked_role(self) -> pulumi.Output[builtins.int]:
        """
        是否是服务关联角色, 0否，1是。
        """
        return pulumi.get(self, "is_service_linked_role")

    @property
    @pulumi.getter(name="maxSessionDuration")
    def max_session_duration(self) -> pulumi.Output[builtins.int]:
        """
        角色最大会话时间，角色最大会话时间。用于限制角色扮演产生的临时安全凭证的有效期的最大范围。取值范围：3600~43200，单位为秒，默认为43200。
        """
        return pulumi.get(self, "max_session_duration")

    @property
    @pulumi.getter
    def policies(self) -> pulumi.Output[Sequence['outputs.RolePolicy']]:
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Output[builtins.int]:
        """
        角色ID。
        """
        return pulumi.get(self, "role_id")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Output[builtins.str]:
        """
        角色名，长度1~64，支持英文、数字和.-_符号。
        """
        return pulumi.get(self, "role_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.RoleTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def trn(self) -> pulumi.Output[builtins.str]:
        """
        角色TRN。
        """
        return pulumi.get(self, "trn")

    @property
    @pulumi.getter(name="trustPolicyDocument")
    def trust_policy_document(self) -> pulumi.Output[builtins.str]:
        """
        角色信任策略，信任策略遵循IAM的策略语法中基于资源的策略规则。
        """
        return pulumi.get(self, "trust_policy_document")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> pulumi.Output[builtins.str]:
        """
        角色更新时间。
        """
        return pulumi.get(self, "update_date")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'EniPrimaryIpAddress',
    'EniPrimaryIpAddressAssociatedElasticIp',
    'EniPrivateIpSet',
    'EniPrivateIpSetAssociatedElasticIp',
    'EniTag',
    'SecurityGroupEgressPermission',
    'SecurityGroupIngressPermission',
    'SecurityGroupTag',
    'SubnetRouteTable',
    'SubnetTag',
    'VpcAssociateCen',
    'VpcTag',
    'GetEniPrimaryIpAddressResult',
    'GetEniPrimaryIpAddressAssociatedElasticIpResult',
    'GetEniPrivateIpSetResult',
    'GetEniPrivateIpSetAssociatedElasticIpResult',
    'GetEniTagResult',
    'GetSecurityGroupEgressPermissionResult',
    'GetSecurityGroupIngressPermissionResult',
    'GetSecurityGroupTagResult',
    'GetSubnetRouteTableResult',
    'GetSubnetTagResult',
    'GetVpcAssociateCenResult',
    'GetVpcTagResult',
]

@pulumi.output_type
class EniPrimaryIpAddress(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "associatedElasticIp":
            suggest = "associated_elastic_ip"
        elif key == "privateIpAddress":
            suggest = "private_ip_address"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in EniPrimaryIpAddress. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        EniPrimaryIpAddress.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        EniPrimaryIpAddress.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 associated_elastic_ip: Optional['outputs.EniPrimaryIpAddressAssociatedElasticIp'] = None,
                 primary: Optional[builtins.bool] = None,
                 private_ip_address: Optional[builtins.str] = None):
        """
        :param 'EniPrimaryIpAddressAssociatedElasticIpArgs' associated_elastic_ip: 网卡主私网IPv4关联的公网IP的信息。
        :param builtins.bool primary: 是否为主私网IPv4地址。
        :param builtins.str private_ip_address: 网卡的私网IP地址。
        """
        if associated_elastic_ip is not None:
            pulumi.set(__self__, "associated_elastic_ip", associated_elastic_ip)
        if primary is not None:
            pulumi.set(__self__, "primary", primary)
        if private_ip_address is not None:
            pulumi.set(__self__, "private_ip_address", private_ip_address)

    @property
    @pulumi.getter(name="associatedElasticIp")
    def associated_elastic_ip(self) -> Optional['outputs.EniPrimaryIpAddressAssociatedElasticIp']:
        """
        网卡主私网IPv4关联的公网IP的信息。
        """
        return pulumi.get(self, "associated_elastic_ip")

    @property
    @pulumi.getter
    def primary(self) -> Optional[builtins.bool]:
        """
        是否为主私网IPv4地址。
        """
        return pulumi.get(self, "primary")

    @property
    @pulumi.getter(name="privateIpAddress")
    def private_ip_address(self) -> Optional[builtins.str]:
        """
        网卡的私网IP地址。
        """
        return pulumi.get(self, "private_ip_address")


@pulumi.output_type
class EniPrimaryIpAddressAssociatedElasticIp(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allocationId":
            suggest = "allocation_id"
        elif key == "eipAddress":
            suggest = "eip_address"
        elif key == "releaseWithInstance":
            suggest = "release_with_instance"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in EniPrimaryIpAddressAssociatedElasticIp. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        EniPrimaryIpAddressAssociatedElasticIp.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        EniPrimaryIpAddressAssociatedElasticIp.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allocation_id: Optional[builtins.str] = None,
                 eip_address: Optional[builtins.str] = None,
                 release_with_instance: Optional[builtins.bool] = None):
        """
        :param builtins.str allocation_id: 公网IP的ID。
        :param builtins.str eip_address: 公网IP的地址。
        :param builtins.bool release_with_instance: 公网IP是否随云服务器实例删除。仅主网卡的主私网IP绑定按量计费公网IP有效。开启后，当云服务器实例被系统自动回收（退订24小时后、到期回收、欠费回收）或被调用DeleteInstances接口时，公网IP随其一同释放，true：是，false：否。
        """
        if allocation_id is not None:
            pulumi.set(__self__, "allocation_id", allocation_id)
        if eip_address is not None:
            pulumi.set(__self__, "eip_address", eip_address)
        if release_with_instance is not None:
            pulumi.set(__self__, "release_with_instance", release_with_instance)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> Optional[builtins.str]:
        """
        公网IP的ID。
        """
        return pulumi.get(self, "allocation_id")

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> Optional[builtins.str]:
        """
        公网IP的地址。
        """
        return pulumi.get(self, "eip_address")

    @property
    @pulumi.getter(name="releaseWithInstance")
    def release_with_instance(self) -> Optional[builtins.bool]:
        """
        公网IP是否随云服务器实例删除。仅主网卡的主私网IP绑定按量计费公网IP有效。开启后，当云服务器实例被系统自动回收（退订24小时后、到期回收、欠费回收）或被调用DeleteInstances接口时，公网IP随其一同释放，true：是，false：否。
        """
        return pulumi.get(self, "release_with_instance")


@pulumi.output_type
class EniPrivateIpSet(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "associatedElasticIp":
            suggest = "associated_elastic_ip"
        elif key == "privateIpAddress":
            suggest = "private_ip_address"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in EniPrivateIpSet. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        EniPrivateIpSet.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        EniPrivateIpSet.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 associated_elastic_ip: Optional['outputs.EniPrivateIpSetAssociatedElasticIp'] = None,
                 private_ip_address: Optional[builtins.str] = None):
        """
        :param 'EniPrivateIpSetAssociatedElasticIpArgs' associated_elastic_ip: 网卡主私网IPv4关联的公网IP的信息。
        :param builtins.str private_ip_address: 网卡的私网IP地址。
        """
        if associated_elastic_ip is not None:
            pulumi.set(__self__, "associated_elastic_ip", associated_elastic_ip)
        if private_ip_address is not None:
            pulumi.set(__self__, "private_ip_address", private_ip_address)

    @property
    @pulumi.getter(name="associatedElasticIp")
    def associated_elastic_ip(self) -> Optional['outputs.EniPrivateIpSetAssociatedElasticIp']:
        """
        网卡主私网IPv4关联的公网IP的信息。
        """
        return pulumi.get(self, "associated_elastic_ip")

    @property
    @pulumi.getter(name="privateIpAddress")
    def private_ip_address(self) -> Optional[builtins.str]:
        """
        网卡的私网IP地址。
        """
        return pulumi.get(self, "private_ip_address")


@pulumi.output_type
class EniPrivateIpSetAssociatedElasticIp(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allocationId":
            suggest = "allocation_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in EniPrivateIpSetAssociatedElasticIp. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        EniPrivateIpSetAssociatedElasticIp.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        EniPrivateIpSetAssociatedElasticIp.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allocation_id: Optional[builtins.str] = None):
        """
        :param builtins.str allocation_id: 公网IP的ID。
        """
        if allocation_id is not None:
            pulumi.set(__self__, "allocation_id", allocation_id)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> Optional[builtins.str]:
        """
        公网IP的ID。
        """
        return pulumi.get(self, "allocation_id")


@pulumi.output_type
class EniTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SecurityGroupEgressPermission(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "cidrIp":
            suggest = "cidr_ip"
        elif key == "portEnd":
            suggest = "port_end"
        elif key == "portStart":
            suggest = "port_start"
        elif key == "prefixListId":
            suggest = "prefix_list_id"
        elif key == "sourceGroupId":
            suggest = "source_group_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SecurityGroupEgressPermission. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SecurityGroupEgressPermission.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SecurityGroupEgressPermission.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cidr_ip: Optional[builtins.str] = None,
                 description: Optional[builtins.str] = None,
                 direction: Optional[builtins.str] = None,
                 policy: Optional[builtins.str] = None,
                 port_end: Optional[builtins.int] = None,
                 port_start: Optional[builtins.int] = None,
                 prefix_list_id: Optional[builtins.str] = None,
                 priority: Optional[builtins.int] = None,
                 protocol: Optional[builtins.str] = None,
                 source_group_id: Optional[builtins.str] = None):
        """
        :param builtins.str cidr_ip: 源地址的IPv4 CIDR或IPv6 CIDR
        :param builtins.str description: 安全组规则的描述信息。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1~ 255个字符。不填保持原有配置。
        :param builtins.str direction: 安全组规则方向。ingress：入方向。egress：出方向
        :param builtins.str policy: 访问策略。即CidrIp 、SourceGroupId 或 PrefixListId 对应的资源访问安全组内的网卡。取值如下：accept：允许；drop：拒绝。
        :param builtins.int port_end: 端口范围结束值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        :param builtins.int port_start: 端口范围起始值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        :param builtins.str prefix_list_id: 前缀列表的ID
        :param builtins.int priority: 安全组规则优先级，数字越小，代表优先级越高。取值范围：1～100。不填默认值：1
        :param builtins.str protocol: 协议类型。tcp、udp、icmp、icmpv6、all
        :param builtins.str source_group_id: 源地址安全组ID。即该安全组中的所有网卡的地址作为源地址。
        """
        if cidr_ip is not None:
            pulumi.set(__self__, "cidr_ip", cidr_ip)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if direction is not None:
            pulumi.set(__self__, "direction", direction)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if port_end is not None:
            pulumi.set(__self__, "port_end", port_end)
        if port_start is not None:
            pulumi.set(__self__, "port_start", port_start)
        if prefix_list_id is not None:
            pulumi.set(__self__, "prefix_list_id", prefix_list_id)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if source_group_id is not None:
            pulumi.set(__self__, "source_group_id", source_group_id)

    @property
    @pulumi.getter(name="cidrIp")
    def cidr_ip(self) -> Optional[builtins.str]:
        """
        源地址的IPv4 CIDR或IPv6 CIDR
        """
        return pulumi.get(self, "cidr_ip")

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        """
        安全组规则的描述信息。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1~ 255个字符。不填保持原有配置。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def direction(self) -> Optional[builtins.str]:
        """
        安全组规则方向。ingress：入方向。egress：出方向
        """
        return pulumi.get(self, "direction")

    @property
    @pulumi.getter
    def policy(self) -> Optional[builtins.str]:
        """
        访问策略。即CidrIp 、SourceGroupId 或 PrefixListId 对应的资源访问安全组内的网卡。取值如下：accept：允许；drop：拒绝。
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter(name="portEnd")
    def port_end(self) -> Optional[builtins.int]:
        """
        端口范围结束值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        """
        return pulumi.get(self, "port_end")

    @property
    @pulumi.getter(name="portStart")
    def port_start(self) -> Optional[builtins.int]:
        """
        端口范围起始值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        """
        return pulumi.get(self, "port_start")

    @property
    @pulumi.getter(name="prefixListId")
    def prefix_list_id(self) -> Optional[builtins.str]:
        """
        前缀列表的ID
        """
        return pulumi.get(self, "prefix_list_id")

    @property
    @pulumi.getter
    def priority(self) -> Optional[builtins.int]:
        """
        安全组规则优先级，数字越小，代表优先级越高。取值范围：1～100。不填默认值：1
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def protocol(self) -> Optional[builtins.str]:
        """
        协议类型。tcp、udp、icmp、icmpv6、all
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="sourceGroupId")
    def source_group_id(self) -> Optional[builtins.str]:
        """
        源地址安全组ID。即该安全组中的所有网卡的地址作为源地址。
        """
        return pulumi.get(self, "source_group_id")


@pulumi.output_type
class SecurityGroupIngressPermission(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "cidrIp":
            suggest = "cidr_ip"
        elif key == "portEnd":
            suggest = "port_end"
        elif key == "portStart":
            suggest = "port_start"
        elif key == "prefixListId":
            suggest = "prefix_list_id"
        elif key == "sourceGroupId":
            suggest = "source_group_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SecurityGroupIngressPermission. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SecurityGroupIngressPermission.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SecurityGroupIngressPermission.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cidr_ip: Optional[builtins.str] = None,
                 description: Optional[builtins.str] = None,
                 direction: Optional[builtins.str] = None,
                 policy: Optional[builtins.str] = None,
                 port_end: Optional[builtins.int] = None,
                 port_start: Optional[builtins.int] = None,
                 prefix_list_id: Optional[builtins.str] = None,
                 priority: Optional[builtins.int] = None,
                 protocol: Optional[builtins.str] = None,
                 source_group_id: Optional[builtins.str] = None):
        """
        :param builtins.str cidr_ip: 源地址的IPv4 CIDR或IPv6 CIDR
        :param builtins.str description: 安全组规则的描述信息。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1~ 255个字符。不填保持原有配置。
        :param builtins.str direction: 安全组规则方向。ingress：入方向。egress：出方向
        :param builtins.str policy: 访问策略。即CidrIp 、SourceGroupId 或 PrefixListId 对应的资源访问安全组内的网卡。取值如下：accept：允许；drop：拒绝。
        :param builtins.int port_end: 端口范围结束值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        :param builtins.int port_start: 端口范围起始值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        :param builtins.str prefix_list_id: 前缀列表的ID
        :param builtins.int priority: 安全组规则优先级，数字越小，代表优先级越高。取值范围：1～100。不填默认值：1
        :param builtins.str protocol: 协议类型。tcp、udp、icmp、icmpv6、all
        :param builtins.str source_group_id: 源地址安全组ID。即该安全组中的所有网卡的地址作为源地址。
        """
        if cidr_ip is not None:
            pulumi.set(__self__, "cidr_ip", cidr_ip)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if direction is not None:
            pulumi.set(__self__, "direction", direction)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if port_end is not None:
            pulumi.set(__self__, "port_end", port_end)
        if port_start is not None:
            pulumi.set(__self__, "port_start", port_start)
        if prefix_list_id is not None:
            pulumi.set(__self__, "prefix_list_id", prefix_list_id)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if source_group_id is not None:
            pulumi.set(__self__, "source_group_id", source_group_id)

    @property
    @pulumi.getter(name="cidrIp")
    def cidr_ip(self) -> Optional[builtins.str]:
        """
        源地址的IPv4 CIDR或IPv6 CIDR
        """
        return pulumi.get(self, "cidr_ip")

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        """
        安全组规则的描述信息。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1~ 255个字符。不填保持原有配置。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def direction(self) -> Optional[builtins.str]:
        """
        安全组规则方向。ingress：入方向。egress：出方向
        """
        return pulumi.get(self, "direction")

    @property
    @pulumi.getter
    def policy(self) -> Optional[builtins.str]:
        """
        访问策略。即CidrIp 、SourceGroupId 或 PrefixListId 对应的资源访问安全组内的网卡。取值如下：accept：允许；drop：拒绝。
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter(name="portEnd")
    def port_end(self) -> Optional[builtins.int]:
        """
        端口范围结束值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        """
        return pulumi.get(self, "port_end")

    @property
    @pulumi.getter(name="portStart")
    def port_start(self) -> Optional[builtins.int]:
        """
        端口范围起始值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        """
        return pulumi.get(self, "port_start")

    @property
    @pulumi.getter(name="prefixListId")
    def prefix_list_id(self) -> Optional[builtins.str]:
        """
        前缀列表的ID
        """
        return pulumi.get(self, "prefix_list_id")

    @property
    @pulumi.getter
    def priority(self) -> Optional[builtins.int]:
        """
        安全组规则优先级，数字越小，代表优先级越高。取值范围：1～100。不填默认值：1
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def protocol(self) -> Optional[builtins.str]:
        """
        协议类型。tcp、udp、icmp、icmpv6、all
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="sourceGroupId")
    def source_group_id(self) -> Optional[builtins.str]:
        """
        源地址安全组ID。即该安全组中的所有网卡的地址作为源地址。
        """
        return pulumi.get(self, "source_group_id")


@pulumi.output_type
class SecurityGroupTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SubnetRouteTable(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "routeTableId":
            suggest = "route_table_id"
        elif key == "routeTableType":
            suggest = "route_table_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SubnetRouteTable. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SubnetRouteTable.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SubnetRouteTable.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 route_table_id: Optional[builtins.str] = None,
                 route_table_type: Optional[builtins.str] = None):
        """
        :param builtins.str route_table_id: 子网关联的路由表ID。
        :param builtins.str route_table_type: 子网关联的路由表的类型。1、System：表示系统路由表。2、Custom：表示自定义路由表。
        """
        if route_table_id is not None:
            pulumi.set(__self__, "route_table_id", route_table_id)
        if route_table_type is not None:
            pulumi.set(__self__, "route_table_type", route_table_type)

    @property
    @pulumi.getter(name="routeTableId")
    def route_table_id(self) -> Optional[builtins.str]:
        """
        子网关联的路由表ID。
        """
        return pulumi.get(self, "route_table_id")

    @property
    @pulumi.getter(name="routeTableType")
    def route_table_type(self) -> Optional[builtins.str]:
        """
        子网关联的路由表的类型。1、System：表示系统路由表。2、Custom：表示自定义路由表。
        """
        return pulumi.get(self, "route_table_type")


@pulumi.output_type
class SubnetTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class VpcAssociateCen(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "cenId":
            suggest = "cen_id"
        elif key == "cenOwnerId":
            suggest = "cen_owner_id"
        elif key == "cenStatus":
            suggest = "cen_status"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VpcAssociateCen. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VpcAssociateCen.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VpcAssociateCen.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cen_id: Optional[builtins.str] = None,
                 cen_owner_id: Optional[builtins.str] = None,
                 cen_status: Optional[builtins.str] = None):
        """
        :param builtins.str cen_id: CEN的ID。
        :param builtins.str cen_owner_id: CEN的用户ID。
        :param builtins.str cen_status: VPC在CEN中的状态。Attaching：加载中，Attached：已加载
        """
        if cen_id is not None:
            pulumi.set(__self__, "cen_id", cen_id)
        if cen_owner_id is not None:
            pulumi.set(__self__, "cen_owner_id", cen_owner_id)
        if cen_status is not None:
            pulumi.set(__self__, "cen_status", cen_status)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[builtins.str]:
        """
        CEN的ID。
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="cenOwnerId")
    def cen_owner_id(self) -> Optional[builtins.str]:
        """
        CEN的用户ID。
        """
        return pulumi.get(self, "cen_owner_id")

    @property
    @pulumi.getter(name="cenStatus")
    def cen_status(self) -> Optional[builtins.str]:
        """
        VPC在CEN中的状态。Attaching：加载中，Attached：已加载
        """
        return pulumi.get(self, "cen_status")


@pulumi.output_type
class VpcTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetEniPrimaryIpAddressResult(dict):
    def __init__(__self__, *,
                 associated_elastic_ip: 'outputs.GetEniPrimaryIpAddressAssociatedElasticIpResult',
                 primary: builtins.bool,
                 private_ip_address: builtins.str):
        """
        :param 'GetEniPrimaryIpAddressAssociatedElasticIpArgs' associated_elastic_ip: 网卡主私网IPv4关联的公网IP的信息。
        :param builtins.bool primary: 是否为主私网IPv4地址。
        :param builtins.str private_ip_address: 网卡的私网IP地址。
        """
        pulumi.set(__self__, "associated_elastic_ip", associated_elastic_ip)
        pulumi.set(__self__, "primary", primary)
        pulumi.set(__self__, "private_ip_address", private_ip_address)

    @property
    @pulumi.getter(name="associatedElasticIp")
    def associated_elastic_ip(self) -> 'outputs.GetEniPrimaryIpAddressAssociatedElasticIpResult':
        """
        网卡主私网IPv4关联的公网IP的信息。
        """
        return pulumi.get(self, "associated_elastic_ip")

    @property
    @pulumi.getter
    def primary(self) -> builtins.bool:
        """
        是否为主私网IPv4地址。
        """
        return pulumi.get(self, "primary")

    @property
    @pulumi.getter(name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        """
        网卡的私网IP地址。
        """
        return pulumi.get(self, "private_ip_address")


@pulumi.output_type
class GetEniPrimaryIpAddressAssociatedElasticIpResult(dict):
    def __init__(__self__, *,
                 allocation_id: builtins.str,
                 eip_address: builtins.str,
                 release_with_instance: builtins.bool):
        """
        :param builtins.str allocation_id: 公网IP的ID。
        :param builtins.str eip_address: 公网IP的地址。
        :param builtins.bool release_with_instance: 公网IP是否随云服务器实例删除。仅主网卡的主私网IP绑定按量计费公网IP有效。开启后，当云服务器实例被系统自动回收（退订24小时后、到期回收、欠费回收）或被调用DeleteInstances接口时，公网IP随其一同释放，true：是，false：否。
        """
        pulumi.set(__self__, "allocation_id", allocation_id)
        pulumi.set(__self__, "eip_address", eip_address)
        pulumi.set(__self__, "release_with_instance", release_with_instance)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> builtins.str:
        """
        公网IP的ID。
        """
        return pulumi.get(self, "allocation_id")

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> builtins.str:
        """
        公网IP的地址。
        """
        return pulumi.get(self, "eip_address")

    @property
    @pulumi.getter(name="releaseWithInstance")
    def release_with_instance(self) -> builtins.bool:
        """
        公网IP是否随云服务器实例删除。仅主网卡的主私网IP绑定按量计费公网IP有效。开启后，当云服务器实例被系统自动回收（退订24小时后、到期回收、欠费回收）或被调用DeleteInstances接口时，公网IP随其一同释放，true：是，false：否。
        """
        return pulumi.get(self, "release_with_instance")


@pulumi.output_type
class GetEniPrivateIpSetResult(dict):
    def __init__(__self__, *,
                 associated_elastic_ip: 'outputs.GetEniPrivateIpSetAssociatedElasticIpResult',
                 primary: builtins.bool,
                 private_ip_address: builtins.str):
        """
        :param 'GetEniPrivateIpSetAssociatedElasticIpArgs' associated_elastic_ip: 网卡主私网IPv4关联的公网IP的信息。
        :param builtins.bool primary: 是否为主私网IPv4地址。
        :param builtins.str private_ip_address: 网卡的私网IP地址。
        """
        pulumi.set(__self__, "associated_elastic_ip", associated_elastic_ip)
        pulumi.set(__self__, "primary", primary)
        pulumi.set(__self__, "private_ip_address", private_ip_address)

    @property
    @pulumi.getter(name="associatedElasticIp")
    def associated_elastic_ip(self) -> 'outputs.GetEniPrivateIpSetAssociatedElasticIpResult':
        """
        网卡主私网IPv4关联的公网IP的信息。
        """
        return pulumi.get(self, "associated_elastic_ip")

    @property
    @pulumi.getter
    def primary(self) -> builtins.bool:
        """
        是否为主私网IPv4地址。
        """
        return pulumi.get(self, "primary")

    @property
    @pulumi.getter(name="privateIpAddress")
    def private_ip_address(self) -> builtins.str:
        """
        网卡的私网IP地址。
        """
        return pulumi.get(self, "private_ip_address")


@pulumi.output_type
class GetEniPrivateIpSetAssociatedElasticIpResult(dict):
    def __init__(__self__, *,
                 allocation_id: builtins.str,
                 eip_address: builtins.str,
                 release_with_instance: builtins.bool):
        """
        :param builtins.str allocation_id: 公网IP的ID。
        :param builtins.str eip_address: 公网IP的地址。
        :param builtins.bool release_with_instance: 公网IP是否随云服务器实例删除。仅主网卡的主私网IP绑定按量计费公网IP有效。开启后，当云服务器实例被系统自动回收（退订24小时后、到期回收、欠费回收）或被调用DeleteInstances接口时，公网IP随其一同释放，true：是，false：否。
        """
        pulumi.set(__self__, "allocation_id", allocation_id)
        pulumi.set(__self__, "eip_address", eip_address)
        pulumi.set(__self__, "release_with_instance", release_with_instance)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> builtins.str:
        """
        公网IP的ID。
        """
        return pulumi.get(self, "allocation_id")

    @property
    @pulumi.getter(name="eipAddress")
    def eip_address(self) -> builtins.str:
        """
        公网IP的地址。
        """
        return pulumi.get(self, "eip_address")

    @property
    @pulumi.getter(name="releaseWithInstance")
    def release_with_instance(self) -> builtins.bool:
        """
        公网IP是否随云服务器实例删除。仅主网卡的主私网IP绑定按量计费公网IP有效。开启后，当云服务器实例被系统自动回收（退订24小时后、到期回收、欠费回收）或被调用DeleteInstances接口时，公网IP随其一同释放，true：是，false：否。
        """
        return pulumi.get(self, "release_with_instance")


@pulumi.output_type
class GetEniTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetSecurityGroupEgressPermissionResult(dict):
    def __init__(__self__, *,
                 cidr_ip: builtins.str,
                 creation_time: builtins.str,
                 description: builtins.str,
                 direction: builtins.str,
                 policy: builtins.str,
                 port_end: builtins.int,
                 port_start: builtins.int,
                 prefix_list_cidrs: Sequence[builtins.str],
                 prefix_list_id: builtins.str,
                 priority: builtins.int,
                 protocol: builtins.str,
                 source_group_id: builtins.str,
                 update_time: builtins.str):
        """
        :param builtins.str cidr_ip: 源地址的IPv4 CIDR或IPv6 CIDR
        :param builtins.str creation_time: 安全组规则创建时间。
        :param builtins.str description: 安全组规则的描述信息。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1~ 255个字符。不填保持原有配置。
        :param builtins.str direction: 安全组规则方向。ingress：入方向。egress：出方向
        :param builtins.str policy: 访问策略。即CidrIp 、SourceGroupId 或 PrefixListId 对应的资源访问安全组内的网卡。取值如下：accept：允许；drop：拒绝。
        :param builtins.int port_end: 端口范围结束值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        :param builtins.int port_start: 端口范围起始值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        :param Sequence[builtins.str] prefix_list_cidrs: 前缀列表的CIDR。
        :param builtins.str prefix_list_id: 前缀列表的ID
        :param builtins.int priority: 安全组规则优先级，数字越小，代表优先级越高。取值范围：1～100。不填默认值：1
        :param builtins.str protocol: 协议类型。tcp、udp、icmp、icmpv6、all
        :param builtins.str source_group_id: 源地址安全组ID。即该安全组中的所有网卡的地址作为源地址。
        :param builtins.str update_time: 安全组规则更新时间。
        """
        pulumi.set(__self__, "cidr_ip", cidr_ip)
        pulumi.set(__self__, "creation_time", creation_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "direction", direction)
        pulumi.set(__self__, "policy", policy)
        pulumi.set(__self__, "port_end", port_end)
        pulumi.set(__self__, "port_start", port_start)
        pulumi.set(__self__, "prefix_list_cidrs", prefix_list_cidrs)
        pulumi.set(__self__, "prefix_list_id", prefix_list_id)
        pulumi.set(__self__, "priority", priority)
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "source_group_id", source_group_id)
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="cidrIp")
    def cidr_ip(self) -> builtins.str:
        """
        源地址的IPv4 CIDR或IPv6 CIDR
        """
        return pulumi.get(self, "cidr_ip")

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> builtins.str:
        """
        安全组规则创建时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        安全组规则的描述信息。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1~ 255个字符。不填保持原有配置。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def direction(self) -> builtins.str:
        """
        安全组规则方向。ingress：入方向。egress：出方向
        """
        return pulumi.get(self, "direction")

    @property
    @pulumi.getter
    def policy(self) -> builtins.str:
        """
        访问策略。即CidrIp 、SourceGroupId 或 PrefixListId 对应的资源访问安全组内的网卡。取值如下：accept：允许；drop：拒绝。
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter(name="portEnd")
    def port_end(self) -> builtins.int:
        """
        端口范围结束值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        """
        return pulumi.get(self, "port_end")

    @property
    @pulumi.getter(name="portStart")
    def port_start(self) -> builtins.int:
        """
        端口范围起始值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        """
        return pulumi.get(self, "port_start")

    @property
    @pulumi.getter(name="prefixListCidrs")
    def prefix_list_cidrs(self) -> Sequence[builtins.str]:
        """
        前缀列表的CIDR。
        """
        return pulumi.get(self, "prefix_list_cidrs")

    @property
    @pulumi.getter(name="prefixListId")
    def prefix_list_id(self) -> builtins.str:
        """
        前缀列表的ID
        """
        return pulumi.get(self, "prefix_list_id")

    @property
    @pulumi.getter
    def priority(self) -> builtins.int:
        """
        安全组规则优先级，数字越小，代表优先级越高。取值范围：1～100。不填默认值：1
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def protocol(self) -> builtins.str:
        """
        协议类型。tcp、udp、icmp、icmpv6、all
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="sourceGroupId")
    def source_group_id(self) -> builtins.str:
        """
        源地址安全组ID。即该安全组中的所有网卡的地址作为源地址。
        """
        return pulumi.get(self, "source_group_id")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        安全组规则更新时间。
        """
        return pulumi.get(self, "update_time")


@pulumi.output_type
class GetSecurityGroupIngressPermissionResult(dict):
    def __init__(__self__, *,
                 cidr_ip: builtins.str,
                 creation_time: builtins.str,
                 description: builtins.str,
                 direction: builtins.str,
                 policy: builtins.str,
                 port_end: builtins.int,
                 port_start: builtins.int,
                 prefix_list_cidrs: Sequence[builtins.str],
                 prefix_list_id: builtins.str,
                 priority: builtins.int,
                 protocol: builtins.str,
                 source_group_id: builtins.str,
                 update_time: builtins.str):
        """
        :param builtins.str cidr_ip: 源地址的IPv4 CIDR或IPv6 CIDR
        :param builtins.str creation_time: 安全组规则创建时间。
        :param builtins.str description: 安全组规则的描述信息。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1~ 255个字符。不填保持原有配置。
        :param builtins.str direction: 安全组规则方向。ingress：入方向。egress：出方向
        :param builtins.str policy: 访问策略。即CidrIp 、SourceGroupId 或 PrefixListId 对应的资源访问安全组内的网卡。取值如下：accept：允许；drop：拒绝。
        :param builtins.int port_end: 端口范围结束值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        :param builtins.int port_start: 端口范围起始值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        :param Sequence[builtins.str] prefix_list_cidrs: 前缀列表的CIDR。
        :param builtins.str prefix_list_id: 前缀列表的ID
        :param builtins.int priority: 安全组规则优先级，数字越小，代表优先级越高。取值范围：1～100。不填默认值：1
        :param builtins.str protocol: 协议类型。tcp、udp、icmp、icmpv6、all
        :param builtins.str source_group_id: 源地址安全组ID。即该安全组中的所有网卡的地址作为源地址。
        :param builtins.str update_time: 安全组规则更新时间。
        """
        pulumi.set(__self__, "cidr_ip", cidr_ip)
        pulumi.set(__self__, "creation_time", creation_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "direction", direction)
        pulumi.set(__self__, "policy", policy)
        pulumi.set(__self__, "port_end", port_end)
        pulumi.set(__self__, "port_start", port_start)
        pulumi.set(__self__, "prefix_list_cidrs", prefix_list_cidrs)
        pulumi.set(__self__, "prefix_list_id", prefix_list_id)
        pulumi.set(__self__, "priority", priority)
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "source_group_id", source_group_id)
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="cidrIp")
    def cidr_ip(self) -> builtins.str:
        """
        源地址的IPv4 CIDR或IPv6 CIDR
        """
        return pulumi.get(self, "cidr_ip")

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> builtins.str:
        """
        安全组规则创建时间。
        """
        return pulumi.get(self, "creation_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        安全组规则的描述信息。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为1~ 255个字符。不填保持原有配置。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def direction(self) -> builtins.str:
        """
        安全组规则方向。ingress：入方向。egress：出方向
        """
        return pulumi.get(self, "direction")

    @property
    @pulumi.getter
    def policy(self) -> builtins.str:
        """
        访问策略。即CidrIp 、SourceGroupId 或 PrefixListId 对应的资源访问安全组内的网卡。取值如下：accept：允许；drop：拒绝。
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter(name="portEnd")
    def port_end(self) -> builtins.int:
        """
        端口范围结束值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        """
        return pulumi.get(self, "port_end")

    @property
    @pulumi.getter(name="portStart")
    def port_start(self) -> builtins.int:
        """
        端口范围起始值。1、当Protocol 传入tcp或udp时，取值范围为1~65535。2、当Protocol 传入icmp、icmpv6或all时，仅支持传入-1，表示不限制端口
        """
        return pulumi.get(self, "port_start")

    @property
    @pulumi.getter(name="prefixListCidrs")
    def prefix_list_cidrs(self) -> Sequence[builtins.str]:
        """
        前缀列表的CIDR。
        """
        return pulumi.get(self, "prefix_list_cidrs")

    @property
    @pulumi.getter(name="prefixListId")
    def prefix_list_id(self) -> builtins.str:
        """
        前缀列表的ID
        """
        return pulumi.get(self, "prefix_list_id")

    @property
    @pulumi.getter
    def priority(self) -> builtins.int:
        """
        安全组规则优先级，数字越小，代表优先级越高。取值范围：1～100。不填默认值：1
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def protocol(self) -> builtins.str:
        """
        协议类型。tcp、udp、icmp、icmpv6、all
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="sourceGroupId")
    def source_group_id(self) -> builtins.str:
        """
        源地址安全组ID。即该安全组中的所有网卡的地址作为源地址。
        """
        return pulumi.get(self, "source_group_id")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        安全组规则更新时间。
        """
        return pulumi.get(self, "update_time")


@pulumi.output_type
class GetSecurityGroupTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetSubnetRouteTableResult(dict):
    def __init__(__self__, *,
                 route_table_id: builtins.str,
                 route_table_type: builtins.str):
        """
        :param builtins.str route_table_id: 子网关联的路由表ID。
        :param builtins.str route_table_type: 子网关联的路由表的类型。1、System：表示系统路由表。2、Custom：表示自定义路由表。
        """
        pulumi.set(__self__, "route_table_id", route_table_id)
        pulumi.set(__self__, "route_table_type", route_table_type)

    @property
    @pulumi.getter(name="routeTableId")
    def route_table_id(self) -> builtins.str:
        """
        子网关联的路由表ID。
        """
        return pulumi.get(self, "route_table_id")

    @property
    @pulumi.getter(name="routeTableType")
    def route_table_type(self) -> builtins.str:
        """
        子网关联的路由表的类型。1、System：表示系统路由表。2、Custom：表示自定义路由表。
        """
        return pulumi.get(self, "route_table_type")


@pulumi.output_type
class GetSubnetTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetVpcAssociateCenResult(dict):
    def __init__(__self__, *,
                 cen_id: builtins.str,
                 cen_owner_id: builtins.str,
                 cen_status: builtins.str):
        """
        :param builtins.str cen_id: CEN的ID。
        :param builtins.str cen_owner_id: CEN的用户ID。
        :param builtins.str cen_status: VPC在CEN中的状态。Attaching：加载中，Attached：已加载
        """
        pulumi.set(__self__, "cen_id", cen_id)
        pulumi.set(__self__, "cen_owner_id", cen_owner_id)
        pulumi.set(__self__, "cen_status", cen_status)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> builtins.str:
        """
        CEN的ID。
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="cenOwnerId")
    def cen_owner_id(self) -> builtins.str:
        """
        CEN的用户ID。
        """
        return pulumi.get(self, "cen_owner_id")

    @property
    @pulumi.getter(name="cenStatus")
    def cen_status(self) -> builtins.str:
        """
        VPC在CEN中的状态。Attaching：加载中，Attached：已加载
        """
        return pulumi.get(self, "cen_status")


@pulumi.output_type
class GetVpcTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'KafkaTriggerKafkaCredentials',
    'SandboxEnv',
    'SandboxInstanceImageInfo',
    'SandboxInstanceTosMountConfig',
    'SandboxInstanceTosMountConfigTosMountPoint',
    'SandboxMetadata',
    'GetKafkaTriggerKafkaCredentialsResult',
    'GetSandboxEnvResult',
    'GetSandboxInstanceImageInfoResult',
    'GetSandboxInstanceTosMountConfigResult',
    'GetSandboxInstanceTosMountConfigTosMountPointResult',
    'GetSandboxMetadataResult',
]

@pulumi.output_type
class KafkaTriggerKafkaCredentials(dict):
    def __init__(__self__, *,
                 mechanism: Optional[builtins.str] = None,
                 password: Optional[builtins.str] = None,
                 username: Optional[builtins.str] = None):
        """
        :param builtins.str mechanism: Kafka 认证机制。取值：PLAIN，SCRAM-SHA-256。
        :param builtins.str password: 创建 Kafka 实例时设置的 SASL/PLAIN 用户密码。
        :param builtins.str username: 创建 Kafka 实例时设置的 SASL/PLAIN 用户名称。
        """
        if mechanism is not None:
            pulumi.set(__self__, "mechanism", mechanism)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def mechanism(self) -> Optional[builtins.str]:
        """
        Kafka 认证机制。取值：PLAIN，SCRAM-SHA-256。
        """
        return pulumi.get(self, "mechanism")

    @property
    @pulumi.getter
    def password(self) -> Optional[builtins.str]:
        """
        创建 Kafka 实例时设置的 SASL/PLAIN 用户密码。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def username(self) -> Optional[builtins.str]:
        """
        创建 Kafka 实例时设置的 SASL/PLAIN 用户名称。
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class SandboxEnv(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 环境变量键。
        :param builtins.str value: 环境变量值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        环境变量键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        环境变量值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class SandboxInstanceImageInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "imageId":
            suggest = "image_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SandboxInstanceImageInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SandboxInstanceImageInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SandboxInstanceImageInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 command: Optional[builtins.str] = None,
                 image: Optional[builtins.str] = None,
                 image_id: Optional[builtins.str] = None,
                 port: Optional[builtins.int] = None):
        """
        :param builtins.str command: 沙箱实例程序的启动命令。如需指定脚本文件，请使用绝对路径，并确保脚本具有相应的可执行权限。
        :param builtins.str image: 沙箱实例使用的已预热镜像地址。
        :param builtins.str image_id: 沙箱实例使用的已预热镜像 ID。
        :param builtins.int port: 沙箱实例镜像监听端口。
        """
        if command is not None:
            pulumi.set(__self__, "command", command)
        if image is not None:
            pulumi.set(__self__, "image", image)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def command(self) -> Optional[builtins.str]:
        """
        沙箱实例程序的启动命令。如需指定脚本文件，请使用绝对路径，并确保脚本具有相应的可执行权限。
        """
        return pulumi.get(self, "command")

    @property
    @pulumi.getter
    def image(self) -> Optional[builtins.str]:
        """
        沙箱实例使用的已预热镜像地址。
        """
        return pulumi.get(self, "image")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[builtins.str]:
        """
        沙箱实例使用的已预热镜像 ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter
    def port(self) -> Optional[builtins.int]:
        """
        沙箱实例镜像监听端口。
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class SandboxInstanceTosMountConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "tosMountPoints":
            suggest = "tos_mount_points"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SandboxInstanceTosMountConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SandboxInstanceTosMountConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SandboxInstanceTosMountConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 enable: Optional[builtins.bool] = None,
                 tos_mount_points: Optional[Sequence['outputs.SandboxInstanceTosMountConfigTosMountPoint']] = None):
        """
        :param builtins.bool enable: 沙箱实例是否启用了实例级别的 TOS 挂载，参数值说明：true：是，false：否。
        """
        if enable is not None:
            pulumi.set(__self__, "enable", enable)
        if tos_mount_points is not None:
            pulumi.set(__self__, "tos_mount_points", tos_mount_points)

    @property
    @pulumi.getter
    def enable(self) -> Optional[builtins.bool]:
        """
        沙箱实例是否启用了实例级别的 TOS 挂载，参数值说明：true：是，false：否。
        """
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter(name="tosMountPoints")
    def tos_mount_points(self) -> Optional[Sequence['outputs.SandboxInstanceTosMountConfigTosMountPoint']]:
        return pulumi.get(self, "tos_mount_points")


@pulumi.output_type
class SandboxInstanceTosMountConfigTosMountPoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bucketPath":
            suggest = "bucket_path"
        elif key == "localMountPath":
            suggest = "local_mount_path"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SandboxInstanceTosMountConfigTosMountPoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SandboxInstanceTosMountConfigTosMountPoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SandboxInstanceTosMountConfigTosMountPoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 bucket_path: Optional[builtins.str] = None,
                 local_mount_path: Optional[builtins.str] = None):
        """
        :param builtins.str bucket_path: 沙箱实例挂载的 TOS 远端目录。
        :param builtins.str local_mount_path: 沙箱实例挂载的 TOS 存储桶本地目录。该目录为沙箱应用已配置的 TOS 存储挂载的本地目录时，系统根据指定的本地目录，修改与之对应的 TOS BucketPath。
        """
        if bucket_path is not None:
            pulumi.set(__self__, "bucket_path", bucket_path)
        if local_mount_path is not None:
            pulumi.set(__self__, "local_mount_path", local_mount_path)

    @property
    @pulumi.getter(name="bucketPath")
    def bucket_path(self) -> Optional[builtins.str]:
        """
        沙箱实例挂载的 TOS 远端目录。
        """
        return pulumi.get(self, "bucket_path")

    @property
    @pulumi.getter(name="localMountPath")
    def local_mount_path(self) -> Optional[builtins.str]:
        """
        沙箱实例挂载的 TOS 存储桶本地目录。该目录为沙箱应用已配置的 TOS 存储挂载的本地目录时，系统根据指定的本地目录，修改与之对应的 TOS BucketPath。
        """
        return pulumi.get(self, "local_mount_path")


@pulumi.output_type
class SandboxMetadata(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetKafkaTriggerKafkaCredentialsResult(dict):
    def __init__(__self__, *,
                 mechanism: builtins.str,
                 password: builtins.str,
                 username: builtins.str):
        """
        :param builtins.str mechanism: Kafka 认证机制。取值：PLAIN，SCRAM-SHA-256。
        :param builtins.str password: 创建 Kafka 实例时设置的 SASL/PLAIN 用户密码。
        :param builtins.str username: 创建 Kafka 实例时设置的 SASL/PLAIN 用户名称。
        """
        pulumi.set(__self__, "mechanism", mechanism)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def mechanism(self) -> builtins.str:
        """
        Kafka 认证机制。取值：PLAIN，SCRAM-SHA-256。
        """
        return pulumi.get(self, "mechanism")

    @property
    @pulumi.getter
    def password(self) -> builtins.str:
        """
        创建 Kafka 实例时设置的 SASL/PLAIN 用户密码。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def username(self) -> builtins.str:
        """
        创建 Kafka 实例时设置的 SASL/PLAIN 用户名称。
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class GetSandboxEnvResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 环境变量键。
        :param builtins.str value: 环境变量值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        环境变量键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        环境变量值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetSandboxInstanceImageInfoResult(dict):
    def __init__(__self__, *,
                 command: builtins.str,
                 image: builtins.str,
                 image_id: builtins.str,
                 port: builtins.int):
        """
        :param builtins.str command: 沙箱实例程序的启动命令。如需指定脚本文件，请使用绝对路径，并确保脚本具有相应的可执行权限。
        :param builtins.str image: 沙箱实例使用的已预热镜像地址。
        :param builtins.str image_id: 沙箱实例使用的已预热镜像 ID。
        :param builtins.int port: 沙箱实例镜像监听端口。
        """
        pulumi.set(__self__, "command", command)
        pulumi.set(__self__, "image", image)
        pulumi.set(__self__, "image_id", image_id)
        pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def command(self) -> builtins.str:
        """
        沙箱实例程序的启动命令。如需指定脚本文件，请使用绝对路径，并确保脚本具有相应的可执行权限。
        """
        return pulumi.get(self, "command")

    @property
    @pulumi.getter
    def image(self) -> builtins.str:
        """
        沙箱实例使用的已预热镜像地址。
        """
        return pulumi.get(self, "image")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        沙箱实例使用的已预热镜像 ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        沙箱实例镜像监听端口。
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class GetSandboxInstanceTosMountConfigResult(dict):
    def __init__(__self__, *,
                 enable: builtins.bool,
                 tos_mount_points: Sequence['outputs.GetSandboxInstanceTosMountConfigTosMountPointResult']):
        """
        :param builtins.bool enable: 沙箱实例是否启用了实例级别的 TOS 挂载，参数值说明：true：是，false：否。
        :param Sequence['GetSandboxInstanceTosMountConfigTosMountPointArgs'] tos_mount_points: 启用了实例级别 TOS 挂载的沙箱实例具体 TOS 挂载目录信息。
        """
        pulumi.set(__self__, "enable", enable)
        pulumi.set(__self__, "tos_mount_points", tos_mount_points)

    @property
    @pulumi.getter
    def enable(self) -> builtins.bool:
        """
        沙箱实例是否启用了实例级别的 TOS 挂载，参数值说明：true：是，false：否。
        """
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter(name="tosMountPoints")
    def tos_mount_points(self) -> Sequence['outputs.GetSandboxInstanceTosMountConfigTosMountPointResult']:
        """
        启用了实例级别 TOS 挂载的沙箱实例具体 TOS 挂载目录信息。
        """
        return pulumi.get(self, "tos_mount_points")


@pulumi.output_type
class GetSandboxInstanceTosMountConfigTosMountPointResult(dict):
    def __init__(__self__, *,
                 bucket_path: builtins.str,
                 local_mount_path: builtins.str):
        """
        :param builtins.str bucket_path: 沙箱实例挂载的 TOS 远端目录。
        :param builtins.str local_mount_path: 沙箱实例挂载的 TOS 存储桶本地目录。该目录为沙箱应用已配置的 TOS 存储挂载的本地目录时，系统根据指定的本地目录，修改与之对应的 TOS BucketPath。
        """
        pulumi.set(__self__, "bucket_path", bucket_path)
        pulumi.set(__self__, "local_mount_path", local_mount_path)

    @property
    @pulumi.getter(name="bucketPath")
    def bucket_path(self) -> builtins.str:
        """
        沙箱实例挂载的 TOS 远端目录。
        """
        return pulumi.get(self, "bucket_path")

    @property
    @pulumi.getter(name="localMountPath")
    def local_mount_path(self) -> builtins.str:
        """
        沙箱实例挂载的 TOS 存储桶本地目录。该目录为沙箱应用已配置的 TOS 存储挂载的本地目录时，系统根据指定的本地目录，修改与之对应的 TOS BucketPath。
        """
        return pulumi.get(self, "local_mount_path")


@pulumi.output_type
class GetSandboxMetadataResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")


